=======
History
=======

0.0.6 (2018-04-06)
------------------
Raise useful errors from the api calls so they are returned to the calling app


0.0.5
-----
Tests
Service helpers

0.0.4
-----

0.0.3 (2018-04-03)
------------------
Store token for 4 hours (issue #7)
Fix some poor documentation
Fix some examples

0.0.2 (2018-04-03)
------------------
Fixing PyPI install not working

0.0.1 (2018-03-26)
------------------

* First release on PyPI.
